<?php
/*
NetworX - open-source social networks platform
Copyright (C) 2009 SocialABC, Inc. http://www.socialabc.com
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program in a file called LICENSE; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/ 

class News extends Entity
{
	public $NewsID 				= -1;
	public $GroupID 			= -1;
	public $UserID 				= -1;
	public $OrganizationID		= -1;
	public $CommunityID			= -1;
	public $NewsDate			= CURRENT_TIME;
	public $NewsName			= '';
	public $NewsKeywords		= '';
	public $NewsText			= '';
	public $NewsViewingPrivacy	= PRIVACY_PUBLIC;
	public $NewsEditingPrivacy	= NEWS_PRIVACY_PUBLIC;


    public function populateFromArray($data)
    {
        parent::populateFromArray($data);
        $this->NewsText = html_entity_decode($this->NewsText);
    }

    public function getNewsPlaceObject()
    {
        switch (true)
        {
            case ($this->GroupID != -1):
                return new Group($this->GroupID);

            case ($this->OrganizationID != -1):
                return new Organization($this->OrganizationID);

            case ($this->CommunityID != -1):
                return new Community($this->CommunityID);

            default:
                return new User($this->UserID);

        }
    }

    public static function getUserGroupsNews($id = -1)
    {
        $result = array();
        $db = DBConnect::getInstance();
        $res = $db->query("select n.* from `news` n where n.GroupID in (select c.GroupID from `connection` c where c.UserID = %d and c.GroupID != -1 and c.ConnectionType in (%d, %d, %d))", $id, CONNECTIONTYPE_MEMBER, CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_OWNER);
        foreach ($res->Data as $row)
        {
            $news = new News(-1);
            $news->populateFromArray($row);
            $result[] = $news;
        }
        return $result;
    }

    public static function getUserOrganizationsNews($id = -1)
    {
        $result = array();
        $db = DBConnect::getInstance();
        $res = $db->query("select n.* from `news` n where n.OrganizationID in (select c.OrganizationID from `connection` c where c.UserID = %d and c.OrganizationID != -1 and c.ConnectionType in (%d, %d, %d))", $id, CONNECTIONTYPE_MEMBER, CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_OWNER);
        foreach ($res->Data as $row)
        {
            $news = new News(-1);
            $news->populateFromArray($row);
            $result[] = $news;
        }
        return $result;
    }

    public static function getUserCommunitiesNews($id = -1)
    {
        $result = array();
        $db = DBConnect::getInstance();
        $res = $db->query("select n.* from `news` n where n.CommunityID in (select c.CommunityID from `connection` c where c.UserID = %d and c.CommunityID != -1 and c.ConnectionType in (%d, %d, %d))", $id, CONNECTIONTYPE_MEMBER, CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_OWNER);

        foreach ($res->Data as $row)
        {
            $news = new News(-1);
            $news->populateFromArray($row);
            $result[] = $news;
        }
        return $result;
    }

	public static function getGroupNews($grid = 0)
	{
		$result = array();
		$db = DBConnect::getInstance();
		$res = $db->query("select * from `news` where `GroupID`=%s", $grid);
		foreach ($res->Data as $row)
		{
			$news = new News(-1);
			$news->populateFromArray($row);
			$result[] = $news;
		}
		return $result;
	}

	public static function getOrganizationNews($organization_id = 0)
	{
		$result = array();
		$db = DBConnect::getInstance();
		$res = $db->query("select * from `news` where OrganizationID=%d", $organization_id);
		foreach ($res->Data as $row)
		{
			$news = new News(-1);
			$news->populateFromArray($row);
			$result[] = $news;
		}
		return $result;
	}

	public static function getCommunityNews($community_id = 0)
	{
		$result = array();
		$db = DBConnect::getInstance();
		$res = $db->query("select * from `news` where CommunityID=%d", $community_id);
		foreach ($res->Data as $row)
		{
			$news = new News(-1);
			$news->populateFromArray($row);
			$result[] = $news;
		}
		return $result;
	}

	public static function getGroupNewsDrafts($group_id = 0, $userID)
	{
		$result = array();

		$db = DBConnect::getInstance();
		$res = $db->query("select * from `newsdraft` where `GroupID`=%d and UserID = %d", $group_id, $userID);

		foreach ($res->Data as $row)
		{
			$news = new NewsDraft(-1);
			$news->populateFromArray($row);
			$result[] = $news;
		}

		return $result;
	}

	public static function getOrganizationNewsDrafts($organization_id = 0)
	{
		$result = array();

		$db = DBConnect::getInstance();
		$res = $db->query("select * from `newsdraft` where `OrganizationID`=%d", $organization_id);

		foreach ($res->Data as $row)
		{
			$news = new NewsDraft(-1);
			$news->populateFromArray($row);
			$result[] = $news;
		}

		return $result;
	}

	public static function getCommunityNewsDrafts($community_id = 0)
	{
		$result = array();

		$db = DBConnect::getInstance();
		$res = $db->query("select * from `newsdraft` where `CommunityID`=%d", $community_id);

		foreach ($res->Data as $row)
		{
			$news = new NewsDraft(-1);
			$news->populateFromArray($row);
			$result[] = $news;
		}

		return $result;
	}

	public static function getUserNews($id = -1)
	{
		$result = array();
		$db = DBConnect::getInstance();
		$res = $db->query("select * from `news` where `UserID`=%s", $id);
		foreach ($res->Data as $row)
		{
			$news = new News(-1);
			$news->populateFromArray($row);
			$result[] = $news;
		}
		return $result;
	}

	public static function getUserNewsCount($id = -1)
	{
		$db = DBConnect::getInstance();
		$res = $db->query("SELECT COUNT(*) AS cnt FROM `news` WHERE `UserID`=%d", $id);

		return $result->Data[0]['cnt'];
	}

	public static function getGroupViewPrivacySettings($group_id)
	{
        $db = DBConnect::getInstance();
		$result = $db->query("SELECT NewsViewingPrivacy FROM `news` WHERE GroupID = %d LIMIT 1", $group_id);

		return $result->Data[0]['NewsViewingPrivacy'];
	}

	public static function getOrganizationViewPrivacySettings($organization_id)
	{
        $db = DBConnect::getInstance();
		$result = $db->query("SELECT NewsViewingPrivacy FROM `news` WHERE OrganizationID = %d LIMIT 1", $organization_id);

		return $result->Data[0]['NewsViewingPrivacy'];
	}

	public static function getGroupEditPrivacySettings($group_id)
	{
        $db = DBConnect::getInstance();
		$result = $db->query("SELECT NewsEditingPrivacy FROM `news` WHERE GroupID = %d LIMIT 1", $group_id);

		return $result->Data[0]['NewsEditingPrivacy'];
	}

	public static function getOrganizationEditPrivacySettings($organization_id)
	{
        $db = DBConnect::getInstance();
		$result = $db->query("SELECT NewsEditingPrivacy FROM `news` WHERE OrganizationID = %d LIMIT 1", $organization_id);

		return $result->Data[0]['NewsEditingPrivacy'];
	}

	public static function setGroupViewPrivacySettings($group_id, $privacy_settings)
	{
        switch ($privacy_settings)
        {
        	case PRIVACY_PRIVATE:	break;
        	case PRIVACY_PUBLIC:	break;
        	default:
        	$privacy_settings = PRIVACY_PUBLIC;
        	break;
		}

    	$db = DBConnect::getInstance();
		$result = $db->update('news', array('NewsViewingPrivacy' => $privacy_settings), 'GroupID = ' . $group_id);

		return $result;
	}

	public static function setOrganizationViewPrivacySettings($organization_id, $privacy_settings)
	{
        switch ($privacy_settings)
        {
        	case PRIVACY_PRIVATE:	break;
        	case PRIVACY_PUBLIC:	break;
        	default:
        	$privacy_settings = PRIVACY_PUBLIC;
        	break;
		}

    	$db = DBConnect::getInstance();
		$result = $db->update('news', array('NewsViewingPrivacy' => $privacy_settings), 'OrganizationID = ' . $organization_id);

		return $result;
	}

	public static function setGroupEditPrivacySettings($group_id, $privacy_settings)
	{
        switch ($privacy_settings)
        {
        	case NEWS_PRIVACY_ADMINS:	break;
        	case NEWS_PRIVACY_MEMBERS:	break;
			case NEWS_PRIVACY_PUBLIC:	break;
        	default:
        	$privacy_settings = NEWS_PRIVACY_PUBLIC;
        	break;
		}

    	$db = DBConnect::getInstance();
		$result = $db->update('news', array('NewsEditingPrivacy' => $privacy_settings), 'GroupID = ' . $group_id);

		return $result;
	}

	public static function setOrganizationEditPrivacySettings($organization_id, $privacy_settings)
	{
        switch ($privacy_settings)
        {
        	case NEWS_PRIVACY_ADMINS:	break;
        	case NEWS_PRIVACY_MEMBERS:	break;
			case NEWS_PRIVACY_PUBLIC:	break;
        	default:
        	$privacy_settings = NEWS_PRIVACY_PUBLIC;
        	break;
		}

    	$db = DBConnect::getInstance();
		$result = $db->update('news', array('NewsEditingPrivacy' => $privacy_settings), 'OrganizationID = ' . $organization_id);

		return $result;
	}

	public function getLatestNews()
	{
		$db = DBConnect::getInstance();
		$res = $db->query("SELECT nv.NewsVersionID AS NewsID, n.GroupID, n.UserID, n.OrganizationID, n.CommunityID, nv.NewsVersionDate AS NewsDate, nv.NewsVersionName AS NewsName, nv.NewsVersionKeywords AS NewsKeywords, nv.NewsVersionText AS NewsText, n.NewsViewingPrivacy, n.NewsEditingPrivacy FROM `newsversion` AS nv INNER JOIN `news` AS n ON n.NewsID = nv.NewsID WHERE nv.NewsID = %d LIMIT 10", $this->NewsID);

		foreach ($res->Data as $row)
		{
			$news = new News(-1);
			$news->populateFromArray($row);
			$result[] = $news;
		}

		return $result;
	}

	public function revertToPreviousVersion($version_id)
	{
        $db = DBConnect::getInstance();

		$res = $db->query("SELECT nv.NewsVersionID AS NewsID, n.GroupID, n.UserID, n.OrganizationID, n.CommunityID, nv.NewsVersionDate AS NewsDate, nv.NewsVersionName AS NewsName, nv.NewsVersionKeywords AS NewsKeywords, nv.NewsVersionText AS NewsText, n.NewsViewingPrivacy, n.NewsEditingPrivacy FROM `newsversion` AS nv INNER JOIN `news` AS n ON n.NewsID = nv.NewsID WHERE nv.NewsVersionID = %d", $version_id);
        $revert_version = new News(-1);
		$revert_version->populateFromArray($res->Data[0]);

		$db->query(
		"UPDATE `news` SET GroupID=%d, UserID=%d, OrganizationID=%d, CommunityID=%d, NewsDate=%s, NewsName=%s, NewsKeywords=%s, NewsText=%s, NewsViewingPrivacy=%d, NewsEditingPrivacy=%d WHERE NewsID = %d",
		$this->GroupID, $this->UserID, $this->OrganizationID, $this->CommunityID, $revert_version->NewsDate, $revert_version->NewsName, $revert_version->NewsKeywords, $revert_version->NewsText, $this->NewsViewingPrivacy, $this->NewsEditingPrivacy, $this->NewsID
		);

		$db->query(
		"UPDATE `newsversion` SET NewsID=%d, NewsVersionDate=%s, NewsVersionName=%s, NewsVersionKeywords=%s, NewsVersionText=%s WHERE NewsVersionID = %d",
		$this->NewsID, $this->NewsDate, $this->NewsName, $this->NewsKeywords, $this->NewsText, $version_id
		);
	}

	public function addVersion()
	{
		$db = DBConnect::getInstance();

		$result = $db->query("SELECT COUNT(*) AS cnt FROM `newsversion` WHERE NewsID = %d", $this->NewsID);
		$cnt = $result->Data[0]['cnt'];

		if ($cnt >= 10)
		{
			$result = $db->query("SELECT NewsVersionID FROM `newsversion` WHERE NewsVersionDate = (SELECT MIN(NewsVersionDate) FROM `newsversion` WHERE NewsID=%d) LIMIT 1", $this->NewsID);
			$first_version_id = $result->Data[0]['NewsVersionID'];

            $db->query(
				"UPDATE `newsversion` SET NewsVersionDate=%s, NewsVersionName=%s, NewsVersionKeywords=%s, NewsVersionText=%s WHERE NewsVersionID=%d",
				$this->NewsDate, $this->NewsName, $this->NewsKeywords, $this->NewsText, $first_version_id
			);
		}
		else
		{
			$db->query("INSERT INTO `newsversion` SET NewsID=%d, NewsVersionDate=%s, NewsVersionName=%s, NewsVersionKeywords=%s, NewsVersionText=%s", $this->NewsID, $this->NewsDate, $this->NewsName, $this->NewsKeywords, $this->NewsText);
		}
	}

	public function deleteNews()
	{
		$db = DBConnect::getInstance();
		$db->query("DELETE FROM `newsversion` WHERE NewsID = %d", $this->NewsID);
		$this->delete();
	}
}
?>