<?php
/*
NetworX - open-source social networks platform
Copyright (C) 2009 SocialABC, Inc. http://www.socialabc.com
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program in a file called LICENSE; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/ 

class Organization extends ConnectionEntity
{
    public $OrganizationID          = -1;
    public $OrganizationName        = "";
    public $OrganizationDescription = "";
    public $OrganizationKeywords    = "";
    public $OrganizationType        = -1;
    public $OrganizationStatus      = ORGANIZATION_STATUS_PUBLIC;
    public $OrganizationPicture     = '';
    public $OrganizationCreated		= '';
    public $OrganizationUpdated		= '';
	public $OrganizationAddress1	= '';
	public $OrganizationAddress2	= '';
	public $OrganizationCity		= '';
	public $OrganizationState		= '';
	public $OrganizationCountry		= '';
	public $OrganizationZip			= '';
	public $OrganizationEmail		= '';
	public $OrganizationWebAddress	= '';
	public $OrganizationPhone		= '';
	public $OrganizationFax			= '';
    public $OrganizationFavouriteWebsites	= '';
    public $OrganizationPermissions = 0;
    public $OrganizationOwner		= -1;
    public $OrganizationActive			= ORGANIZATION_ACTIVE_ACCEPTED;
    public $OrganizationCalendarPrivacy	= CALENDAR_PRIVACY_PUBLIC;
    public $OrganizationIsNonForProfit	= 0;


    public function __construct($entity_id = -1)
    {
    	parent::__construct($entity_id);
    	foreach ($this as $field_id => $field)
    	{
    		if (is_string($field))
    		{
    			$this->{$field_id} = html_entity_decode($field);
    		}
    	}
    }

	public function checkCalendarPrivacy($userID)
	{
		$blnCanSee = true;

		if ($this->OrganizationCalendarPrivacy != CALENDAR_PRIVACY_PUBLIC)
		{
			$blnCanSee = $this->hasMember($userID);

			if ($this->OrganizationCalendarPrivacy == CALENDAR_PRIVACY_PROTECTED)
			{
				$blnCanSee = $blnCanSee || Connection::checkCalendarPrivacy('Organization', $this->OrganizationID, $userID);
			}
		}

		return $blnCanSee;
	}

    public function isMemberBlocked($member_id)
	{
		$connections = Connection::getConnections
		(
			array
			(
				'UserID'	       	=> $member_id,
				'OrganizationID'	=> $this->OrganizationID,
				'UserStatus'		=> MEMBER_STATUS_BLOCKED
			)
		);
		return count($connections) > 0;
	}

	public function getAlbumsCount()
	{
		return Album::getAlbumsCount('Organization', $this->OrganizationID);
	}

	public function getAlbums()
	{
		return Album::getOrganizationAlbums($this->OrganizationID);
	}

    public function isPublic()
    {
    	return $this->OrganizationStatus == ORGANIZATION_STATUS_PUBLIC;
    }

    public function isJoinRequested($id, $entity = 'User')
    {
    	return Message::isOrganizationRequestSent($id, $this->OrganizationID, $entity);
    }

    public function getEvents()
    {
    	return Event::getOrganizationEvents($this->OrganizationID);
    }

	public function isOwner($userID)
    {
    	return ($this->getOwnerID() == $userID) || User::checkEmployer($userID);
    }

	public static function getOrganizations($organization_statuses = array())
	{
		$db = DBConnect::getInstance();
		$params = array();
		$query  = 'SELECT * FROM `organization`';

		if (!empty($organization_statuses))
		{
			$query .= ' WHERE ';
			foreach ($organization_statuses as $organization_status)
			{
				$query .= 'OrganizationStatus = %d OR ';
				$params[] = $organization_status;
			}
			$query = rtrim($query, 'OR ');
		}

		$return = array();
		$result = $db->query($query, $params);
		foreach ($result->Data as $row)
		{
			$organization = new Organization();
			$organization->populateFromArray($row);
			$return[] = $organization;
		}

		return $return;
	}

    public static function getOrganizationsTypes()
    {
        return array(
                "1" => "Fraternity",
                "2" => "Sorority",
                "3" => "College",
                "4" => "Administrative",
                "5" => "Employer");
    }

    public function hasMember($userID)
    {
    	$connections = Connection::getConnections(array('ConnectionType' => array(CONNECTIONTYPE_OWNER,
    		CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_MEMBER),
    		'UserID' => $userID, 'OrganizationID' => $this->OrganizationID));
    	return (count($connections) > 0);
    }

    public function getOwnerID()
    {
        $cons = Connection::getConnections(array('OrganizationID' => $this->OrganizationID, 'ConnectionType' => CONNECTIONTYPE_OWNER));
        return $cons[0]->UserID;
    }

    public function userIsAdmin($userid)
    {
    	$con = Connection::getConnections(array('Flags' => '<> ' . CONNECTIONFLAG_STATUS_SUSPEND,
            'OrganizationID' => $this->OrganizationID, 'ConnectionType' =>
            array(CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_OWNER), 'UserID' => $userid));
    	if (count($con))
    	{
    		return true;
		}
        return User::checkEmployer($userid);
	}

	public function setOwner($user_id)
    {
        $connections = Connection::getConnections(array('ConnectionType' => CONNECTIONTYPE_OWNER, 'OrganizationID' => $this->OrganizationID));
        $connection = count($connections) ? $connections[0] : new Connection();
        $connection->UserID = $user_id;
        $connection->OrganizationID = $this->OrganizationID;
        $connection->ConnectionType = CONNECTIONTYPE_OWNER;
        $connection->saveToDB();

        $organization = new Organization($this->OrganizationID);
        $organization->OrganizationOwner = $user_id;
        $organization->saveToDB();
    }

    public function changeUserStatusInOrganization($user_id, $user_status)
    {
		$db = DBConnect::getInstance();
		$db->update('connection', array('UserStatus' => $user_status), 'UserID = %d AND OrganizationID = %d', $user_id, $this->OrganizationID);
    }

	public function userIsMember($UserID = -1)
	{
		$connections = Connection::getConnections(array('OrganizationID' => $this->OrganizationID, 'UserID' => $UserID));
		return count($connections);
	}

	public function getOrganizationNews()
	{
		return News::getOrganizationNews($this->OrganizationID);
	}

	public function getOrganizationNewsDrafts()
	{
		return News::getOrganizationNewsDrafts($this->OrganizationID);
	}

	public function getOrganizationPhotos($maxcount = 6)
	{
		$db = DBConnect::getInstance();
		$query = $db->query("select p.PhotoID, p.AlbumID, p.PhotoName, p.PhotoPath, p.PhotoStatus, p.PhotoIsCover FROM photo p INNER JOIN album a ON (a.AlbumID = p.AlbumID) AND (a.OrganizationID = %s) ORDER BY PhotoID DESC limit $maxcount", $this->OrganizationID);
		$return = array();
		foreach ($query->Data as $row)
		{
			$photo = new Photo(-1);
			$photo->populateFromArray($row);
			$return[] = $photo;
		}
		return $return;
	}

	public function getPhotos($maxcount = 6)
	{
		return $this->getOrganizationPhotos($maxcount);
	}

	public function getOrganizationVideos($maxcount = 6)
	{
		$return = array();

		$db = DBConnect::getInstance();
		$result = $db->query('select v.* from `video` as v inner join `videoalbum` as a on a.VideoAlbumID = v.VideoAlbumID and a.OrganizationID = %d order by v.VideoID limit ' . $maxcount, $this->OrganizationID);

		foreach ($result->Data as $row)
		{
			$video = new Video();
			$video->populateFromArray($row);

			$return[] = $video;
		}

		return $return;
	}

	public function getVideos($maxcount = 6)
	{
		$this->getOrganizationVideos($maxcount);
	}

	public function getVideoAlbums()
	{
		return VideoAlbum::getOrganizationVideoAlbums($this->OrganizationID);
	}

    public function getPhotoCount()
    {
        return Photo::getOrganizationPhotoCount($this->OrganizationID);
    }

    public function getVideoCount()
    {
        return Video::getOrganizationVideoCount($this->OrganizationID);
    }

	public function getOrganizationFiles($maxcount = 6)
	{
		$return = array();

		$db = DBConnect::getInstance();
		$result = $db->query('select * from file where OrganizationID = %d order by `FileID` limit ' . $maxcount, $this->OrganizationID);

		foreach ($result->Data as $row)
		{
			$file = new File();
			$file->populateFromArray($row);

			$return[] = $file;
		}

		return $return;
	}

	public function getSharedFiles($maxcount = 6)
	{
		$shared_files = SharedFile::getOrganizationFiles($this->OrganizationID);
		return array_slice($shared_files, 0, $maxcount);
	}

	public function getOrganizationAdmins()
	{
		$db = DBConnect::getInstance();
		$query = "SELECT u.* FROM `connection` c INNER JOIN user u USING (UserID) where (c.OrganizationID = %d and c.ConnectionType in (%d, %d))";

		$result = $db->query($query, $this->OrganizationID, CONNECTIONTYPE_OWNER, CONNECTIONTYPE_ADMIN);
		$return = array();
		foreach ($result->Data as $row)
		{
			$user = new User(-1);
			$user->populateFromArray($row);

			$return[] = $user;
		}
		return $return;
	}

	public function getConnections($where = array(), $order = array(), $limit = 0)
	{
		$where['OrganizationID'] = $this->OrganizationID;
		return Connection::getConnections($where, $order, $limit);
    }

    public function getMembers()
    {
        $result = array();

    	$connections = Connection::getConnections(array('ConnectionType' => array(CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_MEMBER, CONNECTIONTYPE_OWNER), 'OrganizationID' => $this->OrganizationID));
    	foreach ($connections as $conn)
    	{
    		$result[] = new User($conn->UserID);
    	}

    	return $result;
    }

	public function getOrganizationMembers($fromgroup = 1)
	{
		$db = DBConnect::getInstance();
		$query = "SELECT u.*, c.* FROM `connection` c INNER JOIN user u USING (UserID) where (c.OrganizationID = %s)";
		if (!$fromgroup)
		{
			$query .= " AND u.UserID NOT IN
				(SELECT c.UserID FROM `connection` c INNER JOIN `connection` cog ON
					(c.GroupID = cog.GroupID) AND (c.GroupID <> -1) AND (cog.OrganizationID = %s)
				)";
		}
		$result = $db->query($query, $this->OrganizationID, $this->OrganizationID);
		$return = array();
		foreach ($result->Data as $row)
		{
			$user = new User(-1);
			$user->populateFromArray($row);
			$connection = new Connection(-1);
			$connection->populateFromArray($row);
			$return[] = $user;
		}
		return $return;
	}


	public function getOrganizationMembersID()
	{
		$db = DBConnect::getInstance();
		$query = "SELECT c.UserID FROM `connection` AS c WHERE (c.OrganizationID = %s) AND (c.UserID <> -1)";
		$result = $db->query($query, $this->OrganizationID);
		$return = array();
		foreach ($result->Data as $row)
		{
			$return[] = $row['UserID'];
		}
		return $return;
	}

	public function getOrganizationMembersCount()
	{
		$db = DBConnect::getInstance();
		$query = $db->query("SELECT COUNT(ConnectionID) AS cc FROM `connection` WHERE (UserID <> '-1') AND (OrganizationID = %s)", $this->OrganizationID);
		return $query->Data['0']['cc'];
	}

	public function getOrganizationGroups()
	{
		$db = DBConnect::getInstance();
		$result = $db->query("select * from `group` g INNER JOIN `connection` c USING (GroupID) where c.OrganizationID = %s", $this->OrganizationID);
		$return = array ();
		foreach ($result->Data as $row)
		{
			$group = new Group(-1);
			$group->populateFromArray($row);
			$return[] = $group;
		}
		return $return;
	}

    public static function getByOrganizationName($name)
	{
		$obj = new Organization();

		if ($name != '')
		{
			$db = DBConnect::getInstance();
			$res = $db->query('SELECT * FROM organization WHERE OrganizationName = %s', $name);

			if ($res->Size > 0)
			{
				$obj->populateFromArray($res->Data[0]);
			}
		}

		return $obj;
	}

	public function getUserStatusInOrganization($user_id)
    {
    	$connections = Connection::getConnections(array('ConnectionType' => array(CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_MEMBER, CONNECTIONTYPE_OWNER), 'OrganizationID' => $this->OrganizationID, 'UserID' => $user_id));
    	$result = $connections[0]->UserStatus;

    	return $result;
    }

	public function getOrganizationOrphanUsers($sort_by = 'UserName', $sort_order = 'ASC')
	{
		$result = array();

    	$organization_id = $this->OrganizationID;
		$db = DBConnect::getInstance();

    	$query = "SELECT DISTINCT u.* FROM `user` AS u
			INNER JOIN `connection` AS c ON c.UserID = u.UserID
			AND (c.OrganizationID = %d) AND (c.ConnectionType = %d OR c.ConnectionType = %d OR c.ConnectionType = %d)
			AND u.UserID NOT IN
			(
				SELECT u1.UserID FROM `user` AS u1
				INNER JOIN `connection` AS c1 ON c1.UserID = u1.UserID
				INNER JOIN `usertoteam` AS utt1 ON utt1.UserID = u1.UserID
				INNER JOIN `team` AS t1 ON t1.OrganizationID = c1.OrganizationID
				AND t1.TeamID = utt1.TeamID
				WHERE (c1.OrganizationID = %d)
			)
			ORDER BY $sort_by $sort_order";

    	$rs = $db->query($query, $organization_id, CONNECTIONTYPE_OWNER, CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_MEMBER, $organization_id);

    	foreach ($rs->Data as $row)
    	{
    		$organization_user = new User();
    		$organization_user->populateFromArray($row);
    		$result[] = $organization_user;
    	}

    	return $result;
	}

	public function getOrganizationPendingUsers()
	{
		return Message::getOrganizationPendingUsers($this->OrganizationID);
	}

	public function getOrganizationTeams($sort_by = 'TeamName', $sort_order = 'ASC')
	{
		return Team::getOrganizationTeams($this->OrganizationID, $sort_by, $sort_order);
	}

    public function addOrganization($orgID, $type = CONNECTIONFLAG_TYPE_UNOFFICIAL)
    {
		if (!$this->hasOrganization($orgID))
		{
			$org = new Organization($orgID);
			if ($org->OrganizationID != -1)
			{
		        $connection = new Connection();
		        $connection->OrganizationID = $orgID;
		        $connection->ToOrganizationID = $this->OrganizationID;
		        $connection->ConnectionType = CONNECTIONTYPE_MEMBER;
		        $connection->Flags = $type;
		        $connection->saveToDB();

		        $members = $this->getOrganizationAdmins();
		        foreach ($members as $member)
		        {
		        	$org->addAdmin($member->UserID);
				}

		        $members = $org->getOrganizationAdmins();
		        foreach ($members as $member)
		        {
		        	$this->addAdmin($member->UserID);
				}
			}
		}
    }

    public function getOwnerUser()
    {
    	$owner = $this;
    	while (get_class($owner) != 'User')
    	{
    		$owner = $owner->getOwner();
		}
		return $owner;
	}

    public function getOwnerUserID()
    {
    	$user = $this->getOwnerUser();
    	return $user->UserID;
	}

    public function addGroup($groupID, $type = CONNECTIONFLAG_TYPE_UNOFFICIAL)
    {
		if (!$this->hasGroup($groupID))
		{
			$group = new Group($groupID);
			if ($group->GroupID != -1)
			{
		        $connection = new Connection();
		        $connection->OrganizationID = $this->OrganizationID;
		        $connection->GroupID = $groupID;
		        $connection->ConnectionType = CONNECTIONTYPE_MEMBER;
		        $connection->Flags = $type;
		        $connection->saveToDB();

		        $members = $this->getOrganizationAdmins();
		        foreach ($members as $member)
		        {
		        	$group->addAdmin($member->UserID);
				}
			}
		}
    }

    public function addCommunity($communityID)
    {
		if (!$this->hasCommunity($communityID))
		{
			$community = new Community($communityID);
			if ($community->CommunityID != -1)
			{
		        $connection = new Connection();
		        $connection->OrganizationID = $this->OrganizationID;
		        $connection->CommunityID = $communityID;
		        $connection->ConnectionType = CONNECTIONTYPE_MEMBER;
		        $connection->saveToDB();
			}
		}
    }


    public function addMember($userID)
    {
		if (!$this->hasMember($userID))
		{
			$member = new User($userID);
			if ($member->UserID != -1)
			{
				$connection = new Connection();
   				$connection->UserID = $userID;
		        $connection->OrganizationID = $this->OrganizationID;
		        $connection->ConnectionType = CONNECTIONTYPE_MEMBER;
		        $connection->saveToDB();
			}
		}
    }

    public function getSentInvitations()
    {
        return SentInvitation::getOrganizationSentInvitations($this->OrganizationID);
    }

    public function hasCommunity($communityID)
    {
    	$connections = Connection::getConnections(array('ConnectionType' => array(CONNECTIONTYPE_MEMBER, CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_OWNER),
    		'CommunityID' => $communityID, 'OrganizationID' => $this->OrganizationID));
    	return (count($connections) > 0);
    }

    public function hasGroup($groupID)
    {
    	return Connection::checkOrganizationGroupConnected($groupID, $this->OrganizationID);
    }

    public function hasOrganization($orgID)
    {
    	return Connection::checkOrganizationsConnected($this->OrganizationID, $orgID);
	}

    public function addAdmin($userID)
    {
    	if (!$this->isOwner($userID))
    	{
			$this->removeMember($userID);

			$member = new User($userID);
			if ($member->UserID != -1)
			{
				$connection = new Connection();
   				$connection->UserID = $userID;
			    $connection->OrganizationID = $this->OrganizationID;
			    $connection->ConnectionType = CONNECTIONTYPE_ADMIN;
			    $connection->saveToDB();
			}
		}
    }

    public function removeOrganization($organizationID)
    {
		$connections = Connection::getConnections(array(
			'ConnectionType' => CONNECTIONTYPE_MEMBER,
    		'ToOrganizationID' => $organizationID, 'OrganizationID' => $this->OrganizationID));

    	foreach ($connections as $connection)
    	{
    		$connection->delete();
    	}

		$connections = Connection::getConnections(array(
			'ConnectionType' => CONNECTIONTYPE_MEMBER,
    		'OrganizationID' => $organizationID, 'ToOrganizationID' => $this->OrganizationID));

    	foreach ($connections as $connection)
    	{
    		$connection->delete();
    	}
    }

	public function removeGroup($groupID)
    {
		$connections = Connection::getConnections(array(
			'ConnectionType' => CONNECTIONTYPE_MEMBER,
    		'OrganizationID' => $this->OrganizationID, 'GroupID' => $groupID));

    	foreach ($connections as $connection)
    	{
    		$connection->delete();
    	}
	}

	public function removeCommunity($communityID)
    {
		$connections = Connection::getConnections(array(
			'ConnectionType' => CONNECTIONTYPE_MEMBER,
    		'OrganizationID' => $this->OrganizationID, 'CommunityID' => $communityID));

    	foreach ($connections as $connection)
    	{
    		$connection->delete();
    	}
	}

    public function getOrganizationUsers()
	{
		$result = array();

    	$db = DBConnect::getInstance();
    	$query =
    		'SELECT u.* FROM `connection` AS c INNER JOIN `organization` AS o ON o.OrganizationID = c.OrganizationID ' .
    		'INNER JOIN `user` AS u ON u.UserID = c.UserID ' .
    		'WHERE o.OrganizationID = %d AND u.UserID IS NOT NULL AND (c.ConnectionType = %d OR c.ConnectionType = %d OR c.ConnectionType = %d)';
    	$rs = $db->query($query, $this->OrganizationID, CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_MEMBER, CONNECTIONTYPE_OWNER);

    	foreach ($rs->Data as $row)
    	{
    		$organization_user = new User();
    		$organization_user->populateFromArray($row);
    		$result[] = $organization_user;
    	}

    	return $result;
	}

    public function removeMember($userID)
    {
		$connections = Connection::getConnections(array('ConnectionType' => CONNECTIONTYPE_MEMBER,
    		'UserID' => $userID, 'OrganizationID' => $this->OrganizationID));
    	foreach ($connections as $connection)
    	{
    		$connection->delete();
    	}
    }

    public function requestJoin($userID)
    {
    	$return = true;

		if ($this->OrganizationStatus != ORGANIZATION_STATUS_PUBLIC)
		{
			$return = Message::sendOrganizationRequest($userID, $this->OrganizationID);
		}
		else
		{
			$this->addMember($userID);
		}

		return $return;
	}

    public function sendGroupRequest($groupID, $messageText, $type = CONNECTIONFLAG_TYPE_UNOFFICIAL)
    {
    	Message::sendGroupRequest('Organization', $this->OrganizationID, $groupID, $messageText, $type);
	}

    public function sendOrganizationRequest($orgID, $messageText, $type = CONNECTIONFLAG_TYPE_UNOFFICIAL)
    {
    	Message::sendOrganizationRequest('Organization', $this->OrganizationID, $orgID, $messageText, $type);
	}

	public function inviteMember($fromUserID, $userID, $message)
	{
		return Message::sendOrganizationInvite($fromUserID, $this->OrganizationID, $userID, $message);
	}

    public static function getUserOrganizations($userID, $owneronly = false)
    {
    	$db = DBConnect::getInstance();
    	if ($owneronly)
    	{
    		$result = $db->query('select o.* from `connection` c inner join `organization` o on o.OrganizationActive = %d and o.OrganizationID = c.OrganizationID ' .
    			'where c.UserID = %d and c.OrganizationID is not null and (c.ConnectionType = %d or c.ConnectionType = %d)',
    			ORGANIZATION_ACTIVE_ACCEPTED, $userID, CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_OWNER);
		}
		else
		{
    		$result = $db->query('SELECT o.* FROM `connection` AS c INNER JOIN `organization` AS o ON o.OrganizationActive = %d AND o.OrganizationID = c.OrganizationID ' .
    			'WHERE c.UserID = %d AND c.OrganizationID IS NOT NULL AND (c.ConnectionType = %d OR c.ConnectionType = %d OR c.ConnectionType = %d)',
                ORGANIZATION_ACTIVE_ACCEPTED, $userID, CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_MEMBER, CONNECTIONTYPE_OWNER);
		}
    	$return = array();

    	foreach ($result->Data as $row)
    	{
    		$org = new Organization();
    		$org->populateFromArray($row);
    		$return[] = $org;
    	}
    	return $return;
    }

    public function getOwnerConnection()
    {
        $cons = Connection::getConnections(array('OrganizationID' => $this->OrganizationID, 'ConnectionType' => CONNECTIONTYPE_OWNER, 'UserID' => '<> -1'));
        return $cons[0];
    }

    public function getOwner()
    {
        $cons = Connection::getConnections(array('OrganizationID' => $this->OrganizationID, 'ConnectionType' => CONNECTIONTYPE_OWNER, 'UserID' => '<> -1'));
        if ($cons[0]->UserID != -1)
        {
            return new User($cons[0]->UserID);
        }
        return -1;
    }

    public function getConnectedGroupInfo()
    {
        $db = DBConnect::getInstance();
        $query = $db->query("SELECT g.* FROM `connection` JOIN `group` AS g USING (GroupID) WHERE (OrganizationID = %s)", $this->OrganizationID);
        return $query->Data;
    }

    public static function nameExists($name, $cur_org_id = 0)
    {
    	$db = DBConnect::getInstance();
    	$rs = $db->query("SELECT OrganizationID FROM `organization` WHERE OrganizationName = %s AND OrganizationID <> %s", $name, $cur_org_id);
    	return ($rs->Size > 0);
	}

    public function removeUserFromOrganizationAdminList($user_id)
	{
		$db = DBConnect::getInstance();
		$db->update('connection', array('ConnectionType' => CONNECTIONTYPE_MEMBER), 'UserID = %d AND OrganizationID = %d', $user_id, $this->OrganizationID);
	}

	public function suicide()
	{
		Location::clearOrganizationLocations($this->OrganizationID);
		SocialGroup::clearOrganizationSocialGroups($this->OrganizationID);

		$cons = Connection::getConnections(array('OrganizationID' => $this->OrganizationID));
		$connection = $cons[0];
		$connection->delete();

		$this->delete();
	}

	public function getNewsViewPrivacySettings()
	{
		return News::getOrganizationViewPrivacySettings($this->OrganizationID);
	}

	public function getNewsEditPrivacySettings()
	{
		return News::getOrganizationEditPrivacySettings($this->OrganizationID);
	}

	public function setNewsViewPrivacySettings($privacy_settings)
	{
		News::setOrganizationViewPrivacySettings($this->OrganizationID, $privacy_settings);
	}

	public function setNewsEditPrivacySettings($privacy_settings)
	{
		News::setOrganizationEditPrivacySettings($this->OrganizationID, $privacy_settings);
	}

	public function getTags()
	{
		return Tag::getOrganizationTags($this->OrganizationID);
	}

	public function checkViewNewsPrivacy()
	{
		global $user;

		if ($this->getNewsViewPrivacySettings() == PRIVACY_PUBLIC)
		{
			$result = true;
		}
		elseif ( ($this->getNewsViewPrivacySettings() == PRIVACY_PRIVATE) && ($this->hasMember($user->UserID)) )
		{
			$result = true;
		}
		else
		{
			$result = false;
		}

		return $result;
	}

	public function checkEditNewsPrivacy()
	{
		global $user;

		if ($this->getNewsEditPrivacySettings() == NEWS_PRIVACY_PUBLIC)
		{
			$result = true;
		}
		elseif ( ($this->getNewsEditPrivacySettings() == NEWS_PRIVACY_ADMINS) && ($this->userIsAdmin($user->UserID)) )
		{
			$result = true;
		}
		elseif ( ($this->getNewsEditPrivacySettings() == NEWS_PRIVACY_MEMBERS) && ($this->hasMember($user->UserID)) )
		{
			$result = true;
		}
		else
		{
			$result = false;
		}

		return $result;
	}

    public function newsBelongsToThisOrganization($news_id)
    {
    	$db = DBConnect::getInstance();
		$result = $db->query("SELECT OrganizationID FROM `news` WHERE NewsID=%d", $news_id);

		return ($result->Data[0]['OrganizationID'] == $this->OrganizationID);
	}

	public function deleteNews($news_id)
	{
        if ($this->checkEditNewsPrivacy() && $this->newsBelongsToThisOrganization($news_id))
        {
	        $news = new News($news_id);
			$news->deleteNews();
		}
	}

	public function getMembersByCompany($company_name)
	{
        $result = array();

        $db = DBConnect::getInstance();
		$res = $db->query("
			SELECT u.* FROM `user` AS u
			INNER JOIN `company` AS c ON c.UserID = u.UserID
			WHERE c.CompanyName LIKE %p", $company_name);

		foreach ($res->Data as $row)
		{
			$user = new User(-1);
			$user->populateFromArray($row);
            if ($this->hasMember($user->UserID))
            {
				$result[] = $user;
			}
		}

		return $result;
	}

	public function getMembersBySkill($skill_name)
	{
        $result = array();

        $db = DBConnect::getInstance();
		$res = $db->query("
			SELECT u.* FROM `user` AS u
			INNER JOIN `skill` AS s ON s.UserID = u.UserID
			WHERE s.SkillName LIKE %p", $skill_name);

		foreach ($res->Data as $row)
		{
			$user = new User(-1);
			$user->populateFromArray($row);
            if ($this->hasMember($user->UserID))
            {
				$result[] = $user;
			}
		}

		return $result;
	}

	public function getMembersBySchool($school_name)
	{
        $result = array();

        $db = DBConnect::getInstance();
		$res = $db->query("
			SELECT u.* FROM `user` AS u
			INNER JOIN `school` AS s ON s.UserID = u.UserID
			WHERE s.SchoolName LIKE %p", $school_name);

		foreach ($res->Data as $row)
		{
			$user = new User(-1);
			$user->populateFromArray($row);
            if ($this->hasMember($user->UserID))
            {
				$result[] = $user;
			}
		}

		return $result;
	}

	public function getMembersByInterest($interest_name)
	{
        $result = array();

        $db = DBConnect::getInstance();
		$res = $db->query("
			SELECT u.* FROM `user` AS u
			INNER JOIN `connection` AS c ON c.UserID = u.UserID
			WHERE c.OrganizationID=%d AND u.UserFavouriteInterests LIKE %p", $this->OrganizationID, $interest_name);

		foreach ($res->Data as $row)
		{
			$user = new User(-1);
			$user->populateFromArray($row);
            if ($this->hasMember($user->UserID))
            {
				$result[] = $user;
			}
		}

		return $result;
	}

	public function getNewMembersCount()
	{
		$db = DBConnect::getInstance();
		$query = $db->query("SELECT COUNT(ConnectionID) AS cc FROM `connection` WHERE (UserID <> '-1') AND (OrganizationID = %s) AND (ConnectionType = %d OR ConnectionType = %d) AND (DATEDIFF(CURDATE(), Created) <= %d)", $this->OrganizationID, CONNECTIONTYPE_MEMBER, CONNECTIONTYPE_ADMIN, PROFILE_UPDATE_PERIOD);
		return $query->Data['0']['cc'];
	}

	public function getNewNewsCount()
	{
		$db = DBConnect::getInstance();
		$query = $db->query("SELECT COUNT(NewsID) AS n FROM `news` WHERE (OrganizationID = %s) AND (DATEDIFF(CURDATE(), NewsDate) <= %d)", $this->OrganizationID, PROFILE_UPDATE_PERIOD);
		return $query->Data['0']['n'];
	}

	public function getNewPhotosCount()
	{
		$db = DBConnect::getInstance();
		$query = $db->query("SELECT COUNT(PhotoID) AS pp FROM `photo` AS p INNER JOIN `album` AS a ON a.AlbumID = p.AlbumID WHERE (a.OrganizationID = %s) AND (DATEDIFF(CURDATE(), p.PhotoCreated) <= %d)", $this->OrganizationID, PROFILE_UPDATE_PERIOD);
		return $query->Data['0']['pp'];
	}

	public function getNewVideosCount()
	{
		$db = DBConnect::getInstance();
		$query = $db->query("SELECT COUNT(VideoID) AS vv FROM `video` AS v INNER JOIN `videoalbum` AS a ON a.VideoAlbumID = v.VideoAlbumID WHERE (a.OrganizationID = %s) AND (DATEDIFF(CURDATE(), v.VideoCreated) <= %d)", $this->OrganizationID, PROFILE_UPDATE_PERIOD);
		return $query->Data['0']['vv'];
	}

	public function getNewFilesCount()
	{
		$db = DBConnect::getInstance();
		$query = $db->query("SELECT COUNT(SharedFileID) AS sf FROM `sharedfile` WHERE (OrganizationID = %s) AND (DATEDIFF(CURDATE(), Updated) <= %d)", $this->OrganizationID, PROFILE_UPDATE_PERIOD);
		return $query->Data['0']['sf'];
	}

	public function getForms()
	{
		return Form::getOrganizationForms($this->OrganizationID);
	}

	public function getName()
	{
		return $this->OrganizationName;
	}
}