<?php
/*
NetworX - open-source social networks platform
Copyright (C) 2009 SocialABC, Inc. http://www.socialabc.com
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program in a file called LICENSE; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/ 

class Video Extends Entity
{
	public $VideoID			= -1;
	public $VideoAlbumID	= -1;
	public $VideoName		= '';
	public $VideoPath		= '';
	public $VideoStatus		= VIDEOSTATUS_NOT_APPROVED;
	public $VideoToken		= '';
	public $VideoCreated	= CURRENT_TIME;


    public function getTags()
    {
    	return Tag::getTags(TAG_TYPE_VIDEO, $this->VideoID);
    }

	public static function getUserVideosSize($userID)
    {
        $db = DBConnect::getInstance();
        $result = $db->query('select * from video v inner join videoalbum a on a.VideoAlbumID = v.VideoAlbumID where a.UserID = %d', $userID);
		$size = 0;
		foreach ($result->Data as $row)
		{
			$obj = new Video();
			$obj->populateFromArray($row);
			$size += filesize($obj->getVideoUrl(true)) + filesize($obj->getVideoUrl(false));
		}
		return $size;
    }


    public static function getUserVideoCountRank($userID)
    {
        $db = DBConnect::getInstance();
        $result = $db->query('select count(*) as cnt, a.UserID from video v inner join videoalbum a on a.VideoAlbumID = v.VideoAlbumID group by a.UserID order by cnt asc');

        for ($i = 0; $i < count($result->Data); $i++)
        {
            if ($userID == $result->Data[$i]['UserID'])
            {
                break;
            }
        }
        return $i + 1;
    }

    public static function getUserVideoCount($userID)
    {
        $db = DBConnect::getInstance();
        $result = $db->query('select count(*) as cnt from video v inner join videoalbum a on a.VideoAlbumID = v.VideoAlbumID where a.UserID = %d', $userID);
        return intval($result->Data[0]['cnt']);
    }

    public static function getGroupVideoCount($groupID)
    {
        $db = DBConnect::getInstance();
        $result = $db->query('select count(*) as cnt from video v inner join videoalbum a on a.VideoAlbumID = v.VideoAlbumID where a.GroupID = %d', $groupID);
        return intval($result->Data[0]['cnt']);
    }

    public static function getOrganizationVideoCount($organizationID)
    {
        $db = DBConnect::getInstance();
        $result = $db->query('select count(*) as cnt from video v inner join videoalbum a on a.VideoAlbumID = v.VideoAlbumID where a.OrganizationID = %d', $organizationID);
        return intval($result->Data[0]['cnt']);
    }

	public static function getVideoAlbumVideos($video_albumID, $first = 0, $last = 999999)
	{
		$return = array();

		$first = is_numeric($first) ? $first : 0;
        $last = is_numeric($last) ? $last : 5;
		if ( ($last -= $first) <= 0)
        {
            $last = 5;
        }

        $db = DBConnect::getInstance();
		$result = $db->query('select * from video where VideoAlbumID = %d order by `VideoID` limit ' . $first . ', ' . $last, $video_albumID);
		foreach ($result->Data as $row)
		{
			$video = new Video();
			$video->populateFromArray($row);

			$return[] = $video;
		}

		return $return;
	}

	public function getVideoURL($preview = true)
	{
		$path = pathinfo($this->VideoPath);
		if (file_exists(PATH_FILEICONS . strtolower($path['extension']) . '.png'))
		{
			return PATH_FILEICONS . strtolower($path['extension']) . '.png';
		}
		else
		{
			return PATH_FILEICONS . 'generic.png';
		}

	}

	public function getVideoComments()
	{
		return Comment::getVideoComments($this->VideoID);
	}

	public function getVideoCommentsCount()
	{
		return Comment::getVideoCommentsCount($this->VideoID);
	}

	public function getVideoAlbum()
	{
		return new VideoAlbum($this->VideoAlbumID);
	}

    public function getYouTubeObject()
    {
		require_once 'Zend/Loader.php'; // the Zend dir must be in your include_path
		Zend_Loader::loadClass('Zend_Gdata_YouTube');
		Zend_Loader::loadClass('Zend_Gdata_ClientLogin');

		$authenticationURL = YOU_TUBE_AUTHENTIFICATION_URL;
		$httpClient = Zend_Gdata_ClientLogin::getHttpClient(
		                                          $username = YOU_TUBE_USERNAME,
		                                          $password = YOU_TUBE_PASSWORD,
		                                          $service = 'youtube',
		                                          $client = null,
		                                          $source = YOU_TUBE_APPLICATION_ID, // a short string identifying your application
		                                          $loginToken = null,
		                                          $loginCaptcha = null,
		                                          $authenticationURL);

		$applicationId = YOU_TUBE_APPLICATION_ID;
		$clientId = YOU_TUBE_CLIENT_ID;
		$developerKey = YOU_TUBE_DEVELOPER_KEY;

		$yt = new Zend_Gdata_YouTube($httpClient, $applicationId, $clientId, $developerKey);

		return $yt;
	}

	public function uploadVideoToYouTube()
	{
        $yt = $this->getYouTubeObject();

		// create a new Zend_Gdata_YouTube_VideoEntry object
		$myVideoEntry = new Zend_Gdata_YouTube_VideoEntry();

		// create a new Zend_Gdata_App_MediaFileSource object
		$filesource = $yt->newMediaFileSource($this->VideoPath);
		// set slug header
		$filesource->setSlug($this->VideoPath);

		// add the filesource to the video entry
		$myVideoEntry->setMediaSource($filesource);

		$myVideoEntry->setVideoTitle($this->VideoName);
		$myVideoEntry->setVideoDescription('Description');
		$myVideoEntry->setVideoCategory('Entertainment'); // Note that category must be a valid YouTube category !

		// set keywords
		$myVideoEntry->SetVideoTags('user, video');

		// upload URI for the currently authenticated user
		$uploadUrl = 'http://uploads.gdata.youtube.com/feeds/users/default/uploads';

		// upload video as private
		$myVideoEntry->setVideoPrivate();

		// try to upload the video, catching
		try
		{
			$newEntry = $yt->insertEntry($myVideoEntry, $uploadUrl, 'Zend_Gdata_YouTube_VideoEntry');
		}
		catch (Zend_Gdata_App_HttpException $httpException)
		{
			echo $httpException->getRawResponseBody();
		}
		catch (Zend_Gdata_App_Exception $e)
		{
			echo $e->getMessage();
		}

		return $newEntry->getVideoId();
	}

	public static function findFlashUrl($entry)
	{
	    foreach ($entry->mediaGroup->content as $content) {
	        if ($content->type === 'application/x-shockwave-flash') {
	            return $content->url;
	        }
	    }
	    return null;
	}

	public function echoVideoPlayer($yt)
	{
        $videoId = $this->VideoToken;
	    $entry = $yt->getVideoEntry($videoId);

	    $videoTitle = $entry->mediaGroup->title;
	    $videoUrl = $this->findFlashUrl($entry);


	    print <<<END
    <b>$videoTitle</b><br />
    <object width="425" height="350">
      <param name="movie" value="${videoUrl}&autoplay=1"></param>
      <param name="wmode" value="transparent"></param>
      <embed src="${videoUrl}&autoplay=0" type="application/x-shockwave-flash" wmode="transparent"
        width=425" height="350"></embed>
    </object>
END;
	}
}
?>