<?php
/*
NetworX - open-source social networks platform
Copyright (C) 2009 SocialABC, Inc. http://www.socialabc.com
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program in a file called LICENSE; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/ 

class VideoAlbum extends Entity
{
	public  $VideoAlbumID			= -1;
	public  $GroupID			= -1;
	public  $UserID				= -1;
	public  $OrganizationID		= -1;
	public  $CommunityID		= -1;
	public  $VideoAlbumName			= '';
	public  $VideoAlbumDescription	= '';
	public  $VideoAlbumPrivacy		= PRIVACY_PUBLIC;

	private $CoverVideo 		= null;

    public function getCover()
    {
        return ICON_VIDEO;
    }


    public function checkPermission($action)
    {
    	global $user;

        $view   = true;
        $edit   = false;
        $delete = false;
        $upload = false;

        $object = $this->getOwner();
        $entity = get_class($object);

	    if ($entity == 'User')
	    {
        	if ($object->UserID == $user->UserID)
        	{
			    $edit   = true;
			    $delete = true;
			    $upload = true;
        	}
        	else if ($this->AlbumPrivacy != PRIVACY_PUBLIC)
        	{
        		$view = false;
        	}
	    }
	    else
	    {
	    	if ($object->{$entity . 'Status'} != GROUP_STATUS_PUBLIC && $object->{$entity . 'Status'} != ORGANIZATION_STATUS_PUBLIC)
	    	{
		        if (!$object->hasMember($user->UserID))
		        {
	        		$view = false;
		        }
			}

	        if ($object->userIsAdmin($user->UserID))
	        {
	        	$view   = true;
			    $edit   = true;
			    $delete = true;

				if ($object->isOwner($user->UserID))
				{
			    	$upload = true;
				}
	        }
            else
            {
                $edit = ($this->UserID == $user->UserID);
            }
	    }

        if ($this->AlbumPrivacy != PRIVACY_PUBLIC)
        {
        	$view = $view || Connection::checkVideoAlbumPrivacy($this->VideoAlbumID, $user->UserID);
		}

        switch ($action)
        {
            case 'view':
                $result = $view;
            	break;

            case 'edit':
            	$result = $edit;
            	break;

            case 'delete':
                $result = $delete;
            	break;

            case 'upload':
                $result = $upload;
            	break;
        }
        return $result;
    }

    public function setOwner($type, $id)
    {
        global $user;
        
        switch ($type)
        {
            case 'user':
                $this->OrganizationID = -1;
                $this->GroupID = -1;
                $this->CommunityID = -1;
                $this->UserID = $id;
                break;
            case 'group':
                $this->OrganizationID = -1;
                $this->GroupID = $id;
                $this->CommunityID = -1;
                $this->UserID = $user->UserID;
                break;
            case 'organization':
                $this->OrganizationID = $id;
                $this->GroupID = -1;
                $this->CommunityID = -1;
                $this->UserID = $user->UserID;
                break;
            case 'community':
                $this->OrganizationID = -1;
                $this->GroupID = -1;
                $this->CommunityID = $id;
                $this->UserID = $user->UserID;
                break;
        }
    }
    public function getOwner()
    {
        global $user;
        $result = $user;

        if ($this->GroupID != -1)
        {
            $result = new Group($this->GroupID);
        }
        elseif ($this->OrganizationID != -1)
        {
            $result = new Organization($this->OrganizationID);
        }
        elseif ($this->CommunityID != -1)
        {
            $result = new Community($this->CommunityID);
        }
        elseif ($this->UserID != -1)
        {
            $result = new User($this->UserID);
        }
        return $result;
    }

    public static function getVideoAlbumsByType($type = 'user', $id = -1)
    {
        switch ($type)
        {
            case 'user':
                return VideoAlbum::getUserVideoAlbums($id);
                break;
            case 'group':
                return VideoAlbum::getGroupVideoAlbums($id);
                break;
            case 'organization':
                return VideoAlbum::getOrganizationVideoAlbums($id);
                break;
            case 'community':
                return VideoAlbum::getCommunityVideoAlbums($id);
                break;
        }
        return array ();
    }


    public static function getUserVideoAlbums($userID)
    {
        $return = array();
        $db = DBConnect::getInstance();
         $query = $db->query('SELECT
             VideoAlbumID, UserID,
             VideoAlbumName, VideoAlbumDescription, VideoAlbumPrivacy
             FROM videoalbum
             WHERE UserID = %d', $userID);
        foreach ($query->Data as $row)
        {
            $video_album = new VideoAlbum();
            $video_album->populateFromArray($row);
            $return[] = $video_album;
        }
        return $return;
    }


    public static function getGroupVideoAlbums($groupID)
    {
        $return = array();
        $db = DBConnect::getInstance();
         $query = $db->query('SELECT
             VideoAlbumID, GroupID, UserID, 
             VideoAlbumName, VideoAlbumDescription, VideoAlbumPrivacy
             FROM videoalbum
             WHERE GroupID = %d', $groupID);
        foreach ($query->Data as $row)
        {
            $video_album = new VideoAlbum();
            $video_album->populateFromArray($row);
            $return[] = $video_album;
        }
        return $return;
    }

    public static function getOrganizationVideoAlbums($organizationID)
    {
        $return = array();
        $db = DBConnect::getInstance();
         $query = $db->query('SELECT
             VideoAlbumID, OrganizationID,
             VideoAlbumName, VideoAlbumDescription, VideoAlbumPrivacy
             FROM videoalbum
             WHERE OrganizationID = %d', $organizationID);
        foreach ($query->Data as $row)
        {
            $video_album = new VideoAlbum();
            $video_album->populateFromArray($row);
            $return[] = $video_album;
        }
        return $return;
    }

    public static function getCommunityVideoAlbums($organizationID)
    {
        $return = array();
        $db = DBConnect::getInstance();
         $query = $db->query('SELECT
             VideoAlbumID, CommunityID,
             VideoAlbumName, VideoAlbumDescription, VideoAlbumPrivacy
             FROM videoalbum
             WHERE CommunityID = %d', $organizationID);
        foreach ($query->Data as $row)
        {
            $video_album = new VideoAlbum();
            $video_album->populateFromArray($row);
            $return[] = $video_album;
        }
        return $return;
    }

    public function getVideosCount()
    {
        $db = DBConnect::getInstance();
        $res = $db->query("select count(VideoID) as `c` from `video` where `VideoAlbumID` = %d", $this->VideoAlbumID);
        return $res->Data['0']['c'];
    }

    public function getVideos($first = 0, $last = 999999)
    {
        return Video::getVideoAlbumVideos($this->VideoAlbumID, $first, $last);
    }

    public function clearCover()
    {
        $db = DBConnect::getInstance();
        $db->query('update video set VideoIsCover = 0 where VideoAlbumID = %d', $this->VideoAlbumID);
    }

    public function delete()
    {
        cmn_remove_directory(PATH_VIDEO_ALBUM_PICS . '/' . $this->VideoAlbumID . '/previews');
        cmn_remove_directory(PATH_VIDEO_ALBUM_PICS . '/' . $this->VideoAlbumID . '/original');
        cmn_remove_directory(PATH_VIDEO_ALBUM_PICS . '/' . $this->VideoAlbumID);
        parent::delete();
    }

	public static function getVideoAlbumsCount($ownerEntity, $ownerID)
	{
		$count = 0;

		$db = DBConnect::getInstance();
		switch ($ownerEntity)
		{
			case 'User':
			case 'Group':
			case 'Organization':
				$result = $db->query('select count(*) as cnt from videoalbum where %f = %d', $ownerEntity . 'ID', $ownerID);
				$count = intval($result->Data[0]['cnt']);
		}
		return $count;
	}

    public function getTags()
    {
    	return Tag::getTags(TAG_TYPE_VIDEO_ALBUM, $this->VideoAlbumID);
    }

}
?>